changeset 13833:c58f1396894e

isnanl: work around icc bug * lib/isnan.c (FUNC): Compute run-time NaN under ICC as well. Signed-off-by: Eric Blake <eblake@redhat.com>
author Eric Blake <eblake@redhat.com>
date Thu, 04 Nov 2010 16:40:41 -0600
parents 992d47604da1
children 108bbfd6f03b
files ChangeLog lib/isnan.c
diffstat 2 files changed, 7 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,8 @@
+2010-11-04  Eric Blake  <eblake@redhat.com>
+
+	isnanl: work around icc bug
+	* lib/isnan.c (FUNC): Compute run-time NaN under ICC as well.
+
 2010-11-03  Eric Blake  <eblake@redhat.com>
 
 	tests: fix compiler warnings
--- a/lib/isnan.c
+++ b/lib/isnan.c
@@ -118,8 +118,8 @@
   /* Be careful to not do any floating-point operation on x, such as x == x,
      because x may be a signaling NaN.  */
 #  if defined __TINYC__ || defined __SUNPRO_C || defined __DECC \
-      || (defined __sgi && !defined __GNUC__)
-  /* The Sun C 5.0 compilers and the Compaq (ex-DEC) 6.4 compilers don't
+      || (defined __sgi && !defined __GNUC__) || defined __ICC
+  /* The Sun C 5.0, Intel ICC 10.0, and Compaq (ex-DEC) 6.4 compilers don't
      recognize the initializers as constant expressions.  The latter compiler
      also fails when constant-folding 0.0 / 0.0 even when constant-folding is
      not required.  The SGI MIPSpro C compiler complains about "floating-point